@@ -1,4 +1,4 @@
-;# $Id: Storable.pm,v 2.00 2002/05/18 16:00:57 ams Exp $
+;# $Id: Storable.pm,v 2.02 2002/05/28 20:22:27 ams Exp $
 ;#
 ;#  Copyright (c) 1995-2000, Raphael Manfredi
 ;#  
@@ -6,6 +6,15 @@
 ;#  in the README file that comes with the distribution.
 ;#
 ;# $Log: Storable.pm,v $
+;# Revision 2.02  2002/05/28 20:22:27  ams
+;# 1. Rework file header handling. (Nicholas Clark)
+;# 2. Add integer.t and safer integer storing code. (Nicholas Clark)
+;#
+;# Revision 2.01  2002/05/21 05:09:32  ams
+;# 1. Declare correct version for Test::More dependency. (Autrijus Tang)
+;# 2. Install in core library directory. (Tatsuhiko Miyagawa)
+;# 3. Mention $canonical in Storable.pm to suppress warning. (Nicholas Clark)
+;#
 ;# Revision 2.00  2002/05/18 16:00:57  ams
 ;# Import Storable 2.00 from perl-current.
 ;#
@@ -71,9 +80,9 @@ package Storable; @ISA = qw(Exporter DynaLoader);
 );
 
 use AutoLoader;
-use vars qw($forgive_me $VERSION);
+use vars qw($canonical $forgive_me $VERSION);
 
-$VERSION = '2.00';
+$VERSION = '2.02';
 *AUTOLOAD = \&AutoLoader::AUTOLOAD;		# Grrr...
 
 #
